@@ -17,8 +17,7 @@ from ctypes import (
     cdll,
     WINFUNCTYPE,
     WinError,
-    create_unicode_buffer,
-    ArgumentError
+    create_unicode_buffer
 )
 
 from typing import Callable, List
@@ -120,9 +119,13 @@ class _ReleaseEvent:
 
 class JavaAccessBridgeWrapper:
     def __init__(self) -> None:
+        logging.debug("Loading WindowsAccessBridge")
         if "WindowsAccessBridge" not in os.environ:
-            raise APIException("Environment variable: WindowsAccessBridge not found")
-        self._wab: cdll = cdll.LoadLibrary(os.environ['WindowsAccessBridge'])
+            raise OSError("Environment variable: WindowsAccessBridge not found")
+        if not os.path.isfile(os.path.normpath(os.environ['WindowsAccessBridge'])):
+            raise FileNotFoundError(f"File not found: {os.environ['WindowsAccessBridge']}")
+        self._wab: cdll = cdll.LoadLibrary(os.path.normpath(os.environ['WindowsAccessBridge']))
+        logging.debug("WindowsAccessBridge loaded succesfully")
         self._define_functions()
         self._define_callbacks()
         self._set_callbacks()
@@ -460,11 +463,7 @@ class JavaAccessBridgeWrapper:
         return key_bindings
 
     def is_same_object(self, context_from: JavaObject, context_to: JavaObject) -> bool:
-        try:
-            return self._wab.isSameObject(self._vmID, context_from, context_to)
-        except ArgumentError as e:
-            logging.error(f"Error matching object={e}")
-            return False
+        return self._wab.isSameObject(self._vmID, context_from, context_to)
 
     def register_callback(self, name: str, callback: Callable[[JavaObject], None]) -> None:
         logging.debug(f"Registering callback={name}")
@@ -483,7 +482,6 @@ class JavaAccessBridgeWrapper:
         setattr(self, name, runner)
         return runner
 
-    # TODO: handle additional values (need to find an element to test this)
     def property_change(self, vmID: c_long, event: JavaObject, source: JavaObject, property, old_value, new_value):
         with _ReleaseEvent(self, vmID, "property_change", event, source):
             if 'property_change' in self._context_callbacks:
